ctdproc package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ctdproc.tests

Submodules
----------

ctdproc.calcs module
--------------------

.. automodule:: ctdproc.calcs
   :members:
   :undoc-members:
   :show-inheritance:

ctdproc.helpers module
----------------------

.. automodule:: ctdproc.helpers
   :members:
   :undoc-members:
   :show-inheritance:

ctdproc.io module
-----------------

.. automodule:: ctdproc.io
   :members:
   :undoc-members:
   :show-inheritance:

ctdproc.proc module
-------------------

.. automodule:: ctdproc.proc
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: ctdproc
   :members:
   :undoc-members:
   :show-inheritance:
